@@ -360,3 +360,15 @@ class EntityCollection(Generic[E]):
 
     def __iter__(self) -> Iterator[E]:
         return iter(self.entities)
+
+
+class RedirectResponse:
+    """Use or subclass the RedirectResponse class to make sure a
+    HTTP found status (302) response is retured, inluding the specified
+    redirect location.
+    """
+
+    location: str
+
+    def __init__(self, location: str):
+        self.location = location
